
import java.awt.event.WindowEvent;
import java.awt.event.WindowAdapter;
import javax.swing.*;

import javax.swing.tree.*;
import javax.swing.table.*;

/**
 *  Explorer Main Class.
 *
 *  <pre>
 *  s@
 *
 *  % java Explorer [fBNg]
 *  []
 *  % java Explorer C:\\Windows
 *
 *  </pre>
 * 
 *@author     tyamada 
 *@created    2000/09/08 
 */
public class Explorer {

	private JFrame frame;
	private TreePanel treePanel;
	private JTable tablePanel;
	private ExplorerModel model;
	private String dirName;

	public Explorer() {
	}

	public void setDirectoryString(String dirName) {
		this.dirName = dirName;
	}

	public FileNode getSystemTreeNode(String dirName) {
		return createFileNode(new java.io.File(dirName));
	}

	public void show() {

		frame = new JFrame("Explorer Application");
		frame.addWindowListener(
			new WindowAdapter() {

				public void windowClosing(WindowEvent e) {
					System.exit(0);
				}
			});

		FileNode root = null;
		if (dirName != null) {
			root = getSystemTreeNode(dirName);
		}
		else {
			root = createTestTree();
		}

		model = new ExplorerModel(root);
		treePanel = new TreePanel();
		tablePanel = new JTable();
		for (int i = 0; i < model.getColumnCount(); i++) {
			TableColumn tc = new TableColumn();
			tc.setIdentifier(model.getColumnName(i));
			tablePanel.addColumn(tc);
		}

		treePanel.setModel(model);
		treePanel.setSelectionModel(model);
		tablePanel.setModel(model);
		JSplitPane split = new JSplitPane(JSplitPane.HORIZONTAL_SPLIT, 
				new JScrollPane(treePanel), 
				new JScrollPane(tablePanel));

		model.addTreeModelListener(treePanel);
		model.addTableModelListener(tablePanel);
		frame.getContentPane().add(split);
		frame.pack();
		frame.setSize(300, 300);
		frame.setVisible(true);
		split.setDividerLocation(0.5);

	}

	public FileNode createFileNode(java.io.File f) {
		SystemFileNode fileNode = new SystemFileNode(f.getName(), f);
		java.io.File[] files = f.listFiles();
		if (files == null) {
			return fileNode;
		}
		for (int i = 0; i < files.length; i++) {
			FileNode fn = createFileNode(files[i]);
			fileNode.addChild(fn);
		}
		return fileNode;
	}

	public FileNode createTestTree() {

		// create root node.
		FileNode root = new Directory("/");

		// create Directory.
		Directory d = new Directory("Directory");
		root.addChild(d);

		// create File and add it to Drectory.
		d.addChild(new File("File"));

		// copy a Directory.
		FileNode copyNode = d.copy();
		d.addChild(copyNode);

		// create Link
		FileNode link = new Link("Link", copyNode);
		link.addChild(new File("File_2"));
		d.addChild(link);

		// create Directory don't have child.
		d.addChild(new Directory("Dhirectory_2"));
		return root;
	}

	/**
	 *  The main program for the Explorer class 
	 *
	 *@param  args  : Directory
	 */
	public static void main(String[] args) {
		Explorer e = new Explorer();
		if (args != null && args.length == 1) {
			e.setDirectoryString(args[0]);
		} else {
		}
		e.show();
	}
}
// Explorer



