/**
 * FileSystemModel.java
 * @author Takeshi Yamada
 */
public class FileSystemModel  {

    protected FileNode root;
    protected FileNode current;
    private static FileSystemModel instance;
    private String[] columnNames = {"Name", "Size"};
    private Object[][] currentNodeInfos;

    public static FileSystemModel getInstance() {
        if (instance == null) {
            instance = new FileSystemModel();
        }
        return instance;
    }

    private FileSystemModel() {}

    public void setRootNode(FileNode root) {
        this.root = root;
    }

    public FileNode getRootNode() {
        return root;
    }

    public void setCurrentNode(FileNode current) {

        this.current = current;

    }

    public FileNode getCurrentNode() {
        return current;
    }

    public Object[] getFileNodeInfos(FileNode fileNode) {
        Object[] info = new Object[2];
        info[0] = fileNode.getName();
        info[1] = new Long(fileNode.getSize());
        return info;
    }

    public void addFileNode(FileNode parent, FileNode child, int index) {
        parent.addChild(index, child);
    }

    public Object[][] getCurrentNodeChildrenInfos() {
        int childrenNum = getChildNodeCount(current);
        int columnNum = getColumnNames().length;
        if (currentNodeInfos == null || currentNodeInfos.length != childrenNum) {
            currentNodeInfos = new Object[childrenNum][columnNum];
        }
        for (int i = 0; i < childrenNum; i++) {
            FileNode child = getChildNode(current, i);
            currentNodeInfos[i] = getFileNodeInfos(child);
        }
        return currentNodeInfos;
    }
    
    public String[] getColumnNames() {
        return columnNames;
    }

    public FileNode getChildNode(FileNode parent, int index) {
        return parent.getChild(index);
    }

    public int getChildNodeCount(FileNode parent) {
        return parent.getChildCount();
    }

    public int getIndexOfChildNode(FileNode parent, FileNode child) {
        return parent.getIndexOfChild(child);
    }

} // FileSystemModel




